@@ -89,13 +89,13 @@ class Client(object):
         """Performs a POST request, returns the response body.  Uses App Engine's urlfetch where available to disable
         SSL certificate checking (which doesn't work with this API because Yandex has 'Yandex Direct' as the CNAME."""
         ts = time.time()
-        if self.logger:
-            self.logger.debug("Fetching %s, args: %s" % (url, args))
-        self.request_count += 1
-        data = urllib2.urlopen(url, args, self.timeout).read()
-        if self.logger:
-            self.logger.debug("Fetching took %f seconds." % (time.time() - ts))
-        return data
+        try:
+            self.request_count += 1
+            return urllib2.urlopen(url, args, self.timeout).read()
+        finally:
+            if self.logger:
+                self.logger.debug("Fetching %s, args: %s, request=%u, took %.2f seconds." \
+                    % (url, args, self.request_count - 1, time.time() - ts))
 
     def __repr__(self):
         return "<yandexdirect.Client application_id=%s login=%s>" % (self.application_id, self.login)
